RCQsModel

Struct RCQsModel 

pub struct RCQsModel { /* private fields */ }
Quasi-Static adaptive probability model for the range coder.

Implementations

Source

impl RCQsModel

pub fn new(compress: bool, symbols: usize, bits: i32, period: i32) -> Self

Creates a new quasi-static probability model.

compress: true for compression, false for decompression. symbols: number of symbols. bits: log2 of total frequency count (must be <= 16). period: max symbols between normalizations.

pub fn with_defaults(compress: bool, symbols: usize) -> Self

Creates a new model with default bits=16 and period=0x400.

pub fn symbols(&self) -> usize

pub fn reset(&mut self)

Reinitializes the model to uniform distribution.

pub fn encode(&mut self, s: u32) -> (u32, u32)

Gets the cumulative and individual frequencies for encoding symbol s.

pub fn decode(&mut self, l: &mut u32, r: &mut u32) -> u32

Returns the symbol corresponding to cumulative frequency l. Updates l to the cumulative frequency and returns (symbol, freq).

pub fn normalize(&self, r: &mut u32)

Normalizes the range by shifting right by bits.